############
#Objective
############
#This function is to rank the variables after B subsampings
#It also removes the highly correlated variables from lower level

##########
#INPUTS
##########

#data: the data object return from the dataclean()
#model: model object from subsamping procedure (B times)

##########
#OUTPUTS
##########
#table: a table shows the ranked variable list  with its frequency (descending order)


##############################
#other note for this function
##############################
#varname: a table showing the variable names Original vs New.
#e.g.
#> varname
#varname varname.new
#1      B1          X1
##2      B2          X2
#3      B3          X3
#4     bmi          X4
#5     age          X5
#6  gender          X6



Ranking<-function(data,model){
  
#  data=data$data                              
#  varname=data$varnameList       Why did this not produce an error?
  
  
  data.X=data[,-dim(data)[2]]
  
    binary.beta=(model$BETA!=0)
        #matrix(ifelse(c(model$BETA)==0,0,1),nrow=dim(model$BETA)[1]) #COEFFICIENT MATRIX OF 0 OR 1 FORMAT
  temp=binary.beta[,-dim(binary.beta)[2]] #REMOVE INTERCEPT COLUMN

    freqs<-colSums(temp) #CALCULATE FREQUENCY
    ranking<-order(freqs,decreasing=TRUE)
    table=data.frame("frequency"=freqs[ranking], "var"=as.character(names(data)[ranking]),stringsAsFactors=FALSE)
    if(sum(table$frequency)!=0){
  
###the following code removes highly correlated variables (redundant) that at lower level
      mat=(stats::cor(as.matrix(data.X[,table[table[,1]>0,2]])))
        remove.seq=NULL
        for(i in 1:dim(mat)[1]){
            remove.seq=c(remove.seq,which(mat[i,-c(1:i)]>0.9999999999)+i)  
        }
        remove.seq=unique(remove.seq) 
        keep.seq=setdiff(1:dim(mat)[1],remove.seq)
        table=table[table[,1]>0,][keep.seq,]
    }
  #table only show variables that at least appear once over B runs after removing redundant variables
#    table$var_original=names(data)[table$var]
    return(list(table=table,Beta=temp))
}

