\name{SURF}
\alias{SURF}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{function to perform variable selection
%%  ~~function to do ... ~~
}
\description{A forward-selection algorithm with variables ranked by
performing LASSO variable selection on subsamples.
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
}
\usage{
SURF(Xo,y,X=NULL,fold=10,Alpha=1,prop=0.1,weights=FALSE,B=1000,C=200,ncores=1,display.progress=TRUE,family=stats::binomial(link="logit"),pval=0.05)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
\item{Xo}{standardised predictor variables}
\item{y}{response variables}
\item{X}{count data which needs to be converted to proportion}
\item{fold}{number of folds for cross-validation in Lasso}
\item{Alpha}{alpha parameter for elastic net}
\item{prop}{proportion of observations left out in subsampling}
\item{weights}{use weighted regression for unbalanced class sizes}
\item{B}{number of subsamples to take}
\item{C}{number of permutations used to estimate null distribution}
\item{ncores}{number of cores to use for parallel computation}
\item{display.progress}{whether SuRF should print a message on
  completion of each task}
\item{family}{The exponential family error for glm fitting}
\item{pval}{The p-value needed to include a variable. This controls the
  number of false positives. The number of false positives is
  approximately geometrically distributed with this probability of success.}
}
\details{
The SuRF algorithm consists of three steps: Subsampling, ranking and
forward selection. The subsampling uses LASSO with cross-validation for
variable selection. The ranking orders variables based on how often they
are selected by LASSO. The forward selection then tests variables in
this order to see whether any should be added to the model. Selection is
performed by hypothesis testing with the null distribution obtained by
permutation. 
}
\value{
An object of class SURF_fit with the following components
\item{Bmod}{Details of LASSO models fitted on subsamples - this is a
  list with components: "Class.Err" gives the cross-validated
  misclassification rate for binomial response or deviance for other response; "Lambda" gives the values of the tuning
  parameter used on each subsample; "BETA" gives the estimated coefficients on each subsample}
\item{trdata}{The data used. The last column is the response variable}
\item{ranklist}{the ranked list of variables with frequency of
  selection. This has components: "table", which shows the frequency with
  which each variable is selected by the subsamplings; and "Beta", which
  gives a table of the variables selected in each subsample.}
\item{selmod}{The list of selected variables by forward selection. This
  has 4 components: "vslist" is the list of variables selected;
  "dist.mat" is sample of the null deviance distribution; "cutoff" is
  the cut-off for selecting each variable; "devlist" is the list of the
  deviances for the selected variables (and the final value is for the
  variable that is not selected).}
\item{family}{The distribution family fitted to the response variable.}
}
%\references{}
\author{Lihui Liu, Toby Kenney \email{tkenney@mathstat.dal.ca}}
%\note{}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{}
\examples{
library(SuRF)
set.seed(1234)
X<-rbind(c(1,2,3,4,5),c(0,2,0,4,0),c(5,4,3,2,1),c(1,1,1,1,1),c(1,0,3,4,0),c(3,3,2,4,2),c(2,5,1,4,3),c(1,2,0,1,2),c(1,2,1,0,1),c(3,2,1,2,3),c(2,4,0,3,1),c(2,1,0,4,3),c(4,3,0,4,2),c(3,1,4,0,2),c(3,4,2,3,1),c(2,0,3,2,0))
Y<-c(0,1,0,0,0,1,1,1,0,0,0,1,0,1,1,1)
SURF(X,Y,B=10,C=100)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{SuRF}
\keyword{Variable Selection}% __ONLY ONE__ keyword per line

